==> netbeans_8.0.2%2Bdfsg1.orig.tar.xz: netbeans-8.0.2/profiler.nbimpl/src/org/netbeans/modules/profiler/nbimpl/providers/GlobalProfilerTypeUtilsImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2011 Sun Microsystems, Inc.
 */
package org.netbeans.modules.profiler.nbimpl.providers;

import java.util.Collection;
import java.util.Collections;
import java.util.Set;
import org.netbeans.api.java.classpath.ClassPath;
import org.netbeans.api.java.classpath.GlobalPathRegistry;
import org.netbeans.api.java.platform.JavaPlatformManager;
import org.netbeans.api.java.source.ClasspathInfo;
import org.netbeans.modules.profiler.api.java.SourceClassInfo;
import org.netbeans.modules.profiler.spi.java.ProfilerTypeUtilsProvider;
import org.netbeans.spi.java.classpath.support.ClassPathSupport;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Jaroslav Bachorik
 */
@ServiceProvider(service=ProfilerTypeUtilsProvider.class)
public class GlobalProfilerTypeUtilsImpl extends BaseProfilerTypeUtilsImpl {
    @Override
    public Collection<SourceClassInfo> getMainClasses() {
        return Collections.EMPTY_LIST;
    }
    
    @Override
    protected ClasspathInfo getClasspathInfo() {
        ClassPath[] cps = prepareClassPaths();
        
        return ClasspathInfo.create(cps[0], cps[1], cps[2]);
    }

    @Override
    protected ClasspathInfo getClasspathInfo(boolean subprojects, boolean source, boolean deps) {
        ClassPath[] cps = prepareClassPaths();
        
        return ClasspathInfo.create(deps ? cps[0] : ClassPath.EMPTY, deps ? cps[1] : ClassPath.EMPTY, source ? cps[2] : ClassPath.EMPTY);
    }
    
    private ClassPath[] prepareClassPaths() {
        Set<ClassPath> srcPaths = GlobalPathRegistry.getDefault().getPaths(ClassPath.SOURCE);
        Set<ClassPath> compilePaths = GlobalPathRegistry.getDefault().getPaths(ClassPath.COMPILE);
        Set<ClassPath> bootPaths = GlobalPathRegistry.getDefault().getPaths(ClassPath.BOOT);
        
        if (bootPaths.isEmpty()) {
            bootPaths = Collections.singleton(JavaPlatformManager.getDefault().getDefaultPlatform().getBootstrapLibraries());
        }
        
        ClassPath[] cps = new ClassPath[3];
        cps[0] = ClassPathSupport.createProxyClassPath(bootPaths.toArray(new ClassPath[bootPaths.size()]));
        cps[1] = ClassPathSupport.createProxyClassPath(compilePaths.toArray(new ClassPath[compilePaths.size()]));
        cps[2] = ClassPathSupport.createProxyClassPath(srcPaths.toArray(new ClassPath[srcPaths.size()]));
        
        return cps;
    }
}

==> netbeans_8.2%2Bdfsg1.orig.tar.xz: netbeans-8.2/profiler.nbimpl/src/org/netbeans/modules/profiler/nbimpl/providers/GlobalProfilerTypeUtilsImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2011 Sun Microsystems, Inc.
 */
package org.netbeans.modules.profiler.nbimpl.providers;

import java.util.Collection;
import java.util.Collections;
import java.util.Set;
import org.netbeans.api.java.classpath.ClassPath;
import org.netbeans.api.java.classpath.GlobalPathRegistry;
import org.netbeans.api.java.platform.JavaPlatformManager;
import org.netbeans.api.java.source.ClasspathInfo;
import org.netbeans.modules.profiler.api.java.SourceClassInfo;
import org.netbeans.modules.profiler.spi.java.ProfilerTypeUtilsProvider;
import org.netbeans.spi.java.classpath.support.ClassPathSupport;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Jaroslav Bachorik
 */
@ServiceProvider(service=ProfilerTypeUtilsProvider.class)
public class GlobalProfilerTypeUtilsImpl extends BaseProfilerTypeUtilsImpl {
    @Override
    public Collection<SourceClassInfo> getMainClasses() {
        return Collections.EMPTY_LIST;
    }
    
    @Override
    protected ClasspathInfo getClasspathInfo() {
        ClassPath[] cps = prepareClassPaths();
        
        return ClasspathInfo.create(cps[0], cps[1], cps[2]);
    }

    @Override
    protected ClasspathInfo getClasspathInfo(boolean subprojects, boolean source, boolean deps) {
        ClassPath[] cps = prepareClassPaths();
        
        return ClasspathInfo.create(deps ? cps[0] : ClassPath.EMPTY, deps ? cps[1] : ClassPath.EMPTY, source ? cps[2] : ClassPath.EMPTY);
    }
    
    private ClassPath[] prepareClassPaths() {
        Set<ClassPath> srcPaths = GlobalPathRegistry.getDefault().getPaths(ClassPath.SOURCE);
        Set<ClassPath> compilePaths = GlobalPathRegistry.getDefault().getPaths(ClassPath.COMPILE);
        Set<ClassPath> bootPaths = GlobalPathRegistry.getDefault().getPaths(ClassPath.BOOT);
        
        if (bootPaths.isEmpty()) {
            bootPaths = Collections.singleton(JavaPlatformManager.getDefault().getDefaultPlatform().getBootstrapLibraries());
        }
        
        ClassPath[] cps = new ClassPath[3];
        cps[0] = ClassPathSupport.createProxyClassPath(bootPaths.toArray(new ClassPath[0]));
        cps[1] = ClassPathSupport.createProxyClassPath(compilePaths.toArray(new ClassPath[0]));
        cps[2] = ClassPathSupport.createProxyClassPath(srcPaths.toArray(new ClassPath[0]));
        
        return cps;
    }
}
